# -*- coding: utf-8 -*-
# Generated by Django 1.10.1 on 2016-09-06 20:58
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_teams', '0002_ownership_approved'),
    ]

    operations = [
        migrations.AddField(
            model_name='team',
            name='description',
            field=models.TextField(blank=True, null=True),
        ),
        migrations.AlterField(
            model_name='team',
            name='users',
            field=models.ManyToManyField(blank=True, null=True, related_name='team_member', through='django_teams.TeamStatus', to=settings.AUTH_USER_MODEL),
        ),
        migrations.AlterField(
            model_name='teamstatus',
            name='comment',
            field=models.CharField(default='', max_length=255),
        ),
        migrations.AlterField(
            model_name='teamstatus',
            name='role',
            field=models.IntegerField(choices=[(1, 'Requesting Access'), (10, 'Team Member'), (20, 'Team Leader')]),
        ),
    ]
