# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-17 18:45
from __future__ import unicode_literals

from django.conf import settings
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_teams', '0004_auto_20171117_1818'),
    ]

    operations = [
        migrations.AlterField(
            model_name='team',
            name='users',
            field=models.ManyToManyField(blank=True, related_name='team_member', through='django_teams.TeamStatus', to=settings.AUTH_USER_MODEL),
        ),
    ]
