# -*- coding: utf-8 -*-
# Generated by Django 1.11.7 on 2017-11-17 18:18
from __future__ import unicode_literals

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('django_teams', '0003_auto_20160906_2058'),
    ]

    operations = [
        migrations.AlterField(
            model_name='teamstatus',
            name='comment',
            field=models.CharField(blank=True, default=b'', max_length=255, null=True),
        ),
    ]
