{% extends 'base.html' %}
{% load teams %}

{% block page-header %}
    <h1>{{ object }} <small>detailed information</small></h1>
    <p class="lead">{{ object.description }}</p>
{% endblock %}

{% block content %}
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">Teachers</h3>
        </div>
        <div class="panel-body row">
            {% for owner in owners %}
                <div class="col-sm-6 col-md-2">
                    {% with object=owner %}
                    <a class="thumbnail">{% include owner|load_fragment_template %}</a>
                    {% endwith %}
                </div>
            {% endfor %}
        </div>
    </div>
    
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">Classroom Members</h3>
        </div>
        <div class="panel-body row">
            {% for member in members %}
                <div class="col-sm-6 col-md-2">
                    {% with object=member %}
                    <a class="thumbnail">{% include member|load_fragment_template %}</a>
                    {% endwith %}
                </div>
            {% endfor %}
        </div>
    </div>
    <div class="panel panel-default">
        <div class="panel-heading">
            <h3 class="panel-title">Approved Objects</h3>
        </div>
        <div class="panel-body row">
          {% for type in approved_objects_types %}
            {% for owned in type %}
              <div class="col-sm-6 col-md-2">
                  {% with object=owned %}
                  <a class="thumbnail">{% include object|load_fragment_template %}</a>
                  {% endwith %}
              </div>
            {% endfor %}
          {% endfor %}
        </div>
    </div>
{% endblock %}
